{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#clean_vcf.cwl",
            "label": "clean-vcf",
            "doc": "This tool will clean a VCF for use in the OxoG workflow.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#clean_vcf.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/clean_vcf.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cleaned.vcf"
                    },
                    "id": "#clean_vcf.cwl/clean-vcf/clean_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#extract_snv.cwl",
            "label": "extract_snvs",
            "doc": "This tool will extract SNVs from INDEL VCFs\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#extract_snv.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.extracted-SNVs.vcf.gz"
                    },
                    "id": "#extract_snv.cwl/extract_snvs/extracted_snvs"
                }
            ],
            "baseCommand": "/opt/oxog_scripts/extract_snvs_from_indels.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#normalize.cwl",
            "label": "normalize",
            "doc": "This tool will normalize an INDEL VCF using bcf-tools norm.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#normalize.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#normalize.cwl/ref",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".fai"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#normalize.cwl/normalized-vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.normalized.vcf.gz"
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/normalize.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#pass-filter.cwl",
            "label": "pass-filter",
            "doc": "This tool will pass-filter a VCF.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#pass-filter.cwl/vcfdir",
                    "type": "Directory",
                    "doc": "The directory containing the files"
                },
                {
                    "id": "#pass-filter.cwl/filesToFilter",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The names of the files that will actually be filtered"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.pass-filtered.vcf.gz"
                    },
                    "id": "#pass-filter.cwl/pass-filter/output"
                }
            ],
            "arguments": [
                "$(inputs.vcfdir.path)",
                "$(inputs.filesToFilter)"
            ],
            "baseCommand": "/opt/oxog_scripts/pass_filter.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "Workflow",
            "doc": "This workflow will perform preprocessing steps on VCFs for the OxoG/Variantbam/Annotation workflow.\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/mergedVcfs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/normalizedVcfs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/extractedSnvs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/cleanedVcfs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nfunction filterForIndels(inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length ; i++)\n\t{\n\t\tif (inArr[i].basename.indexOf(\"indel\") >= 0)\n\t\t{\n\t\t\tarr.push(inArr[i]);\n\t\t}\n\t}\n\treturn arr;\n}\n\n/**\n * workflowName - the name of the workflow to filter for.\n * vcfType - the type of VCF (snv, indel, etc...)\n * inArr - an array of files (File[]) to search through.\n */\nfunction filterFor(workflowName, vcfType, inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length; i++)\n\t{\n\t\tif (typeof(inArr[i]) == \"string\") //(\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t{\n\t\t\tif (inArr[i].indexOf(workflowName) >= 0 && inArr[i].indexOf(vcfType) >= 0)\n\t\t\t{\n\t\t\t\tarr.push(inArr[i])\n\t\t\t}\n\t\t}\n\t\telse\n\t\t{\n\t\t\tif (\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t\t{\n\t\t\t\tif (inArr[i].basename.indexOf(workflowName) >= 0 && inArr[i].basename.indexOf(vcfType) >= 0)\n\t\t\t\t{\n\t\t\t\t\tarr.push(inArr[i])\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t}\n\treturn arr;\n}\n",
                        "\nfunction formatArray(arr)\n{\n\tvar files = \"\";\n\tfor (var i = 0; i < arr.length; i++)\n\t{\n\t\tfiles = files.concat(arr[i].path,\",\");\n\t}\n\treturn files;\n}\n"
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/vcfdir",
                    "type": "Directory",
                    "doc": "The directory where the files are"
                },
                {
                    "id": "#main/filesToPreprocess",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The files to process"
                },
                {
                    "id": "#main/ref",
                    "type": "File",
                    "doc": "Reference file, used for normalized INDELs"
                },
                {
                    "id": "#main/out_dir",
                    "type": "string",
                    "doc": "The name of the output directory"
                }
            ],
            "outputs": [
                {
                    "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                    "outputSource": "#main/populate_output_record/output_record",
                    "id": "#main/preprocessedFiles"
                }
            ],
            "steps": [
                {
                    "doc": "Clean the VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/clean/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean/clean_vcf"
                    ],
                    "id": "#main/clean"
                },
                {
                    "doc": "Clean the MUSE VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean_muse/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/gather_muse_snvs_for_cleaning/snvs_for_cleaning",
                            "id": "#main/clean_muse/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean_muse/clean_vcf"
                    ],
                    "id": "#main/clean_muse"
                },
                {
                    "doc": "Extract SNVs from normalized INDELs",
                    "run": "#extract_snv.cwl",
                    "scatter": "#main/extract_snv/vcf",
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/extract_snv/vcf"
                        }
                    ],
                    "out": [
                        "#main/extract_snv/extracted_snvs"
                    ],
                    "id": "#main/extract_snv"
                },
                {
                    "doc": "Filters the input list and selects the INDEL VCFs.",
                    "in": [
                        {
                            "source": "#main/gather_clean_vcfs/all_cleaned_vcfs",
                            "id": "#main/filter_for_indel/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_for_indel/out_vcf"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/fac93442-7586-48fe-adaf-79644fed14e4/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/fac93442-7586-48fe-adaf-79644fed14e4/out_vcf"
                            }
                        ],
                        "expression": "$({ out_vcf: filterForIndels(inputs.in_vcf) })\n",
                        "id": "#main/filter_for_indel/fac93442-7586-48fe-adaf-79644fed14e4"
                    },
                    "id": "#main/filter_for_indel"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_broad_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_indels/c4ad36c7-f09b-4fa6-b102-06bcc9b438f4/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_indels/c4ad36c7-f09b-4fa6-b102-06bcc9b438f4/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"broad-snowman\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_broad_indels/c4ad36c7-f09b-4fa6-b102-06bcc9b438f4"
                    },
                    "id": "#main/gather_broad_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/gather_clean_vcfs/all_cleaned_vcfs",
                            "id": "#main/gather_broad_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_broad_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/922c8442-71e4-443e-b8d7-61de6766511d/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/922c8442-71e4-443e-b8d7-61de6766511d/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/922c8442-71e4-443e-b8d7-61de6766511d/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"broad-mutect\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"broad-mutect\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_broad_snvs/922c8442-71e4-443e-b8d7-61de6766511d"
                    },
                    "id": "#main/gather_broad_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_broad_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_svs/2dff753f-7265-4350-a5af-a7fb02a2100e/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_svs/2dff753f-7265-4350-a5af-a7fb02a2100e/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"broad-dRanger_snowman\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_broad_svs/2dff753f-7265-4350-a5af-a7fb02a2100e"
                    },
                    "id": "#main/gather_broad_svs"
                },
                {
                    "doc": "combine cleaned VCFs (MUSE and non-MUSE)",
                    "in": [
                        {
                            "source": "#main/clean_muse/clean_vcf",
                            "id": "#main/gather_clean_vcfs/clean_muse_vcfs"
                        },
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_clean_vcfs/clean_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_clean_vcfs/all_cleaned_vcfs"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_clean_vcfs/213034b3-06eb-44fa-b742-9bfbfab617d3/clean_muse_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_clean_vcfs/213034b3-06eb-44fa-b742-9bfbfab617d3/clean_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_clean_vcfs/213034b3-06eb-44fa-b742-9bfbfab617d3/all_cleaned_vcfs"
                            }
                        ],
                        "expression": "$({\n    all_cleaned_vcfs: inputs.clean_vcfs.concat(inputs.clean_muse_vcfs)\n})\n",
                        "id": "#main/gather_clean_vcfs/213034b3-06eb-44fa-b742-9bfbfab617d3"
                    },
                    "id": "#main/gather_clean_vcfs"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_dkfz_embl_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_indels/aa7a025f-d04e-467b-b21c-4114a59b2180/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_indels/aa7a025f-d04e-467b-b21c-4114a59b2180/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"dkfz-indelCalling\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_dkfz_embl_indels/aa7a025f-d04e-467b-b21c-4114a59b2180"
                    },
                    "id": "#main/gather_dkfz_embl_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/gather_clean_vcfs/all_cleaned_vcfs",
                            "id": "#main/gather_dkfz_embl_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_dkfz_embl_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/0721d0fa-f9dd-4790-9d54-011b3a59a31c/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/0721d0fa-f9dd-4790-9d54-011b3a59a31c/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/0721d0fa-f9dd-4790-9d54-011b3a59a31c/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"dkfz-snvCalling\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"dkfz-snvCalling\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_dkfz_embl_snvs/0721d0fa-f9dd-4790-9d54-011b3a59a31c"
                    },
                    "id": "#main/gather_dkfz_embl_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_dkfz_embl_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_svs/0d9646c9-09a3-43e6-88dd-671f4abd29c8/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_svs/0d9646c9-09a3-43e6-88dd-671f4abd29c8/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"embl-delly\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_dkfz_embl_svs/0d9646c9-09a3-43e6-88dd-671f4abd29c8"
                    },
                    "id": "#main/gather_dkfz_embl_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/gather_clean_vcfs/all_cleaned_vcfs",
                            "id": "#main/gather_muse_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_muse_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_muse_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/c2f416d9-f080-4546-af8a-ac1d4517d9a2/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/c2f416d9-f080-4546-af8a-ac1d4517d9a2/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/c2f416d9-f080-4546-af8a-ac1d4517d9a2/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( filterFor(\"MUSE\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"MUSE\",\"snv_mnv\",inputs.extracted_snvs))\n})\n",
                        "id": "#main/gather_muse_snvs/c2f416d9-f080-4546-af8a-ac1d4517d9a2"
                    },
                    "id": "#main/gather_muse_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/gather_muse_snvs_for_cleaning/vcfdir"
                        },
                        {
                            "source": "#main/filesToPreprocess",
                            "id": "#main/gather_muse_snvs_for_cleaning/vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_muse_snvs_for_cleaning/snvs_for_cleaning"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": "Directory",
                                "id": "#main/gather_muse_snvs_for_cleaning/543b1452-8353-4103-ab6b-6b03116bfedf/vcfdir"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "string"
                                },
                                "id": "#main/gather_muse_snvs_for_cleaning/543b1452-8353-4103-ab6b-6b03116bfedf/vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs_for_cleaning/543b1452-8353-4103-ab6b-6b03116bfedf/snvs_for_cleaning"
                            }
                        ],
                        "expression": "$({\n    snvs_for_cleaning: (  filterFor(\"MUSE\",\"snv_mnv\", inputs.vcfs ).map(function(e) {\n        e = { \"class\":\"File\", \"location\":inputs.vcfdir.location+\"/\"+e }\n        return e;\n    } )  )\n})\n",
                        "id": "#main/gather_muse_snvs_for_cleaning/543b1452-8353-4103-ab6b-6b03116bfedf"
                    },
                    "id": "#main/gather_muse_snvs_for_cleaning"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_sanger_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_indels/0931d96c-5e21-4e83-baf7-050cf27e7f9e/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_indels/0931d96c-5e21-4e83-baf7-050cf27e7f9e/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"svcp\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_sanger_indels/0931d96c-5e21-4e83-baf7-050cf27e7f9e"
                    },
                    "id": "#main/gather_sanger_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/gather_clean_vcfs/all_cleaned_vcfs",
                            "id": "#main/gather_sanger_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_sanger_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/022764ad-7926-4f67-86ba-e20d198683f7/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/022764ad-7926-4f67-86ba-e20d198683f7/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/022764ad-7926-4f67-86ba-e20d198683f7/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"svcp\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"svcp\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_sanger_snvs/022764ad-7926-4f67-86ba-e20d198683f7"
                    },
                    "id": "#main/gather_sanger_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_sanger_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_svs/c38aba06-5eb8-4aa1-b140-8dce78c05b77/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_svs/c38aba06-5eb8-4aa1-b140-8dce78c05b77/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"svfix\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_sanger_svs/c38aba06-5eb8-4aa1-b140-8dce78c05b77"
                    },
                    "id": "#main/gather_sanger_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_smufin_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_smufin_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_smufin_indels/0b882bee-6276-4d3c-83bb-90b95cf1395a/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_smufin_indels/0b882bee-6276-4d3c-83bb-90b95cf1395a/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"smufin\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_smufin_indels/0b882bee-6276-4d3c-83bb-90b95cf1395a"
                    },
                    "id": "#main/gather_smufin_indels"
                },
                {
                    "doc": "Perform VCF merge by type (SNV, SV, INDEL) across workflows.",
                    "run": "#vcf_merge.cwl",
                    "in": [
                        {
                            "source": "#main/gather_broad_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/broad_indel"
                        },
                        {
                            "source": "#main/gather_broad_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/broad_snv"
                        },
                        {
                            "source": "#main/gather_broad_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/broad_sv"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/de_indel"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/de_snv"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/de_sv"
                        },
                        {
                            "source": "#main/gather_muse_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/muse_snv"
                        },
                        {
                            "source": "#main/out_dir",
                            "id": "#main/merge_vcfs/out_dir"
                        },
                        {
                            "source": "#main/gather_sanger_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/sanger_indel"
                        },
                        {
                            "source": "#main/gather_sanger_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/sanger_snv"
                        },
                        {
                            "source": "#main/gather_sanger_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/sanger_sv"
                        },
                        {
                            "source": "#main/gather_smufin_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/smufin_indel"
                        }
                    ],
                    "out": [
                        "#main/merge_vcfs/output"
                    ],
                    "id": "#main/merge_vcfs"
                },
                {
                    "doc": "Normalize the INDEL VCFs.",
                    "run": "#normalize.cwl",
                    "scatter": "#main/normalize/vcf",
                    "in": [
                        {
                            "source": "#main/ref",
                            "id": "#main/normalize/ref"
                        },
                        {
                            "source": "#main/filter_for_indel/out_vcf",
                            "id": "#main/normalize/vcf"
                        }
                    ],
                    "out": [
                        "#main/normalize/normalized-vcf"
                    ],
                    "id": "#main/normalize"
                },
                {
                    "in": [
                        {
                            "source": "#main/extract_snv/extracted_snvs",
                            "id": "#main/null_filter_extracted_snvs/extracted_snvs"
                        },
                        {
                            "source": "#main/clean_muse/clean_vcf",
                            "id": "#main/null_filter_extracted_snvs/muse_files"
                        }
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": [
                                        "File",
                                        "null"
                                    ]
                                },
                                "id": "#main/null_filter_extracted_snvs/5227c206-7950-4be7-99af-ba9dc9fbb1e5/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/null_filter_extracted_snvs/5227c206-7950-4be7-99af-ba9dc9fbb1e5/cleaned_extracted_snvs"
                            }
                        ],
                        "expression": "$(\n    { cleaned_extracted_snvs: inputs.extracted_snvs.filter(function(n){return n != null}) }\n)\n",
                        "id": "#main/null_filter_extracted_snvs/5227c206-7950-4be7-99af-ba9dc9fbb1e5"
                    },
                    "out": [
                        "#main/null_filter_extracted_snvs/cleaned_extracted_snvs"
                    ],
                    "id": "#main/null_filter_extracted_snvs"
                },
                {
                    "doc": "Filter out non-PASS lines from the VCFs in filesToProcess.",
                    "in": [
                        {
                            "source": [
                                "#main/filesToPreprocess"
                            ],
                            "valueFrom": "${\n    var VCFs = []\n    for (var i in self)\n    {\n        if (self[i].toLowerCase().indexOf(\"muse\") == -1)\n        {\n            VCFs.push(self[i]);\n        }\n    }\n    return VCFs;\n}\n",
                            "id": "#main/pass_filter/filesToFilter"
                        },
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/pass_filter/vcfdir"
                        }
                    ],
                    "run": "#pass-filter.cwl",
                    "out": [
                        "#main/pass_filter/output"
                    ],
                    "id": "#main/pass_filter"
                },
                {
                    "in": [
                        {
                            "source": "#main/gather_clean_vcfs/all_cleaned_vcfs",
                            "id": "#main/populate_output_record/cleanedVcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/populate_output_record/extractedSnvs"
                        },
                        {
                            "source": "#main/merge_vcfs/output",
                            "id": "#main/populate_output_record/mergedVcfs"
                        },
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/populate_output_record/normalizedVcfs"
                        }
                    ],
                    "out": [
                        "#main/populate_output_record/output_record"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/2fbe50a9-20c9-4466-a953-391fabd9e3e7/cleanedVcfs"
                            },
                            {
                                "type": [
                                    "null",
                                    {
                                        "type": "array",
                                        "items": "File"
                                    }
                                ],
                                "id": "#main/populate_output_record/2fbe50a9-20c9-4466-a953-391fabd9e3e7/extractedSnvs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/2fbe50a9-20c9-4466-a953-391fabd9e3e7/mergedVcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/2fbe50a9-20c9-4466-a953-391fabd9e3e7/normalizedVcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                                "id": "#main/populate_output_record/2fbe50a9-20c9-4466-a953-391fabd9e3e7/output_record"
                            }
                        ],
                        "expression": "$(\n    {output_record: {\n        \"cleanedVcfs\": inputs.cleanedVcfs,\n        \"mergedVcfs\": inputs.mergedVcfs,\n        \"extractedSnvs\": inputs.extractedSnvs,\n        \"normalizedVcfs\": inputs.normalizedVcfs\n    }}\n)\n",
                        "id": "#main/populate_output_record/2fbe50a9-20c9-4466-a953-391fabd9e3e7"
                    },
                    "id": "#main/populate_output_record"
                }
            ],
            "id": "#main",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#vcf_merge.cwl",
            "label": "merge_vcfs",
            "doc": "This tool will merge VCFs by type (SV, SNV, INDEL). This CWL wrapper was written by Solomon Shorser.\nThe Perl script was originaly written by Brian O'Connor and maintained by Solomon Shorser.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nfunction formatArray(arr)\n{\n\tvar files = \"\";\n\tfor (var i = 0; i < arr.length; i++)\n\t{\n\t\tfiles = files.concat(arr[i].path,\",\");\n\t}\n\treturn files;\n}\n"
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#vcf_merge.cwl/broad_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/muse_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/broad_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/broad_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/smufin_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/out_dir",
                    "type": "string",
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--outdir"
                    }
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.clean.sorted.vcf.gz"
                    },
                    "id": "#vcf_merge.cwl/merge_vcfs/output"
                }
            ],
            "arguments": [
                {
                    "prefix": "--broad_snv",
                    "valueFrom": "$(formatArray(inputs.broad_snv))"
                },
                {
                    "prefix": "--sanger_snv",
                    "valueFrom": "$(formatArray(inputs.sanger_snv))"
                },
                {
                    "prefix": "--dkfz_embl_snv",
                    "valueFrom": "$(formatArray(inputs.de_snv))"
                },
                {
                    "prefix": "--muse_snv",
                    "valueFrom": "$(formatArray(inputs.muse_snv))"
                },
                {
                    "prefix": "--broad_sv",
                    "valueFrom": "$(formatArray(inputs.broad_sv))"
                },
                {
                    "prefix": "--sanger_sv",
                    "valueFrom": "$(formatArray(inputs.sanger_sv))"
                },
                {
                    "prefix": "--dkfz_embl_sv",
                    "valueFrom": "$(formatArray(inputs.de_sv))"
                },
                {
                    "prefix": "--broad_indel",
                    "valueFrom": "$(formatArray(inputs.broad_indel))"
                },
                {
                    "prefix": "--sanger_indel",
                    "valueFrom": "$(formatArray(inputs.sanger_indel))"
                },
                {
                    "prefix": "--dkfz_embl_indel",
                    "valueFrom": "$(formatArray(inputs.de_indel))"
                },
                {
                    "prefix": "--smufin_indel",
                    "valueFrom": "$(formatArray(inputs.smufin_indel))"
                }
            ],
            "baseCommand": "/opt/oxog_scripts/vcf_merge_by_type.pl",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        }
    ],
    "cwlVersion": "v1.0"
}
